summaryrefslogtreecommitdiff
path: root/lib/ansible/utils/module_docs_fragments/netapp.py
diff options
context:
space:
mode:
Diffstat (limited to 'lib/ansible/utils/module_docs_fragments/netapp.py')
-rw-r--r--lib/ansible/utils/module_docs_fragments/netapp.py42
1 files changed, 38 insertions, 4 deletions
diff --git a/lib/ansible/utils/module_docs_fragments/netapp.py b/lib/ansible/utils/module_docs_fragments/netapp.py
index 3629f2c453..653d4d1d20 100644
--- a/lib/ansible/utils/module_docs_fragments/netapp.py
+++ b/lib/ansible/utils/module_docs_fragments/netapp.py
@@ -1,5 +1,5 @@
#
-# (c) 2016, Sumit Kumar <sumit4@netapp.com>
+# (c) 2018, Sumit Kumar <sumit4@netapp.com>, chris Archibald <carchi@netapp.com>
#
# This file is part of Ansible
#
@@ -28,8 +28,8 @@ notes:
- Ansible modules are available for the following NetApp Storage Platforms: E-Series, ONTAP, SolidFire
"""
- # Documentation fragment for ONTAP
- ONTAP = """
+ # Documentation fragment for ONTAP (na_ontap)
+ NA_ONTAP = """
options:
hostname:
required: true
@@ -46,14 +46,48 @@ options:
description:
- Password for the specified user.
aliases: ['pass']
+ https:
+ description:
+ - Enable and disabled https
+ type: bool
+ default: false
+
+requirements:
+ - A physical or virtual clustered Data ONTAP system. The modules were developed with Clustered Data ONTAP 9.3
+ - Ansible 2.6
+ - netapp-lib (2017.10.30). Install using 'pip install netapp-lib'
+ - To enable http on the cluster you must run the following commands 'set -privilege advanced;' 'system services web modify -http-enabled true;'
+notes:
+ - The modules prefixed with na\\_ontap are built to support the ONTAP storage platform.
+
+ """
+
+ # Documentation fragment for ONTAP (na_cdot)
+ ONTAP = """
+options:
+ hostname:
+ required: true
+ description:
+ - The hostname or IP address of the ONTAP instance.
+ username:
+ required: true
+ description:
+ - This can be a Cluster-scoped or SVM-scoped account, depending on whether a Cluster-level or SVM-level API is required.
+ For more information, please read the documentation U(https://goo.gl/BRu78Z).
+ aliases: ['user']
+ password:
+ required: true
+ description:
+ - Password for the specified user.
+ aliases: ['pass']
requirements:
- A physical or virtual clustered Data ONTAP system. The modules were developed with Clustered Data ONTAP 8.3
- Ansible 2.2
- netapp-lib (2015.9.25). Install using 'pip install netapp-lib'
notes:
- - The modules prefixed with C(netapp\\_cdot) are built to support the ONTAP storage platform.
+ - The modules prefixed with na\\_cdot are built to support the ONTAP storage platform.
"""